==> haskell-sandwich-0.2.0.0-60-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.2.0.0
visibility:           public
id:                   sandwich-0.2.0.0-AuhBqVbVkdM38iBqd8Bzz5
key:                  sandwich-0.2.0.0-AuhBqVbVkdM38iBqd8Bzz5
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  8762fd46e7aebc1cdd5d011010d619ac
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util
    Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.RunTimes
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types
    Test.Sandwich.Golden.Update Test.Sandwich.Internal.Formatters
    Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.2.0.0-AuhBqVbVkdM38iBqd8Bzz5
depends:
    aeson-2.1.2.1-Eu0ZMA1fvZJ7acphaZ1YUp
    ansi-terminal-1.0.2-3ZetLec9Al83HbTC6rcVId
    async-2.2.5-CA4aEq3ECoz7BppWAZygZ1 base-4.17.2.1
    brick-2.2-GedRkbOOCdrENtMmRKW6qU bytestring-0.11.5.3
    colour-2.3.6-JQk97xPN0JfIXlQGuAtpoj containers-0.6.7
    deepseq-1.4.8.0 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 free-5.2-ATEZ1D3AF584jLsjFZTsM3
    haskell-src-exts-1.23.1-2lufjAYFsklKfsR8XpwH3n
    lifted-async-0.10.2.7-HWv9dv6tA2M9qihTmkNkf0
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-control-1.0.3.1-JhIUlMwO22REEhKxuYKLpf
    monad-logger-0.3.42-DrHCRPfjPL123BQSo1tVeq mtl-2.2.2
    optparse-applicative-0.18.1.0-9usJKW05Tg77TzGdDpbTqq
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp process-1.6.18.0
    safe-0.3.21-29OHNU5kqwB6czdAzMhG9H
    safe-exceptions-0.1.7.4-2FJBdfOuy5GJXMppmu6xCS stm-2.5.1.0
    string-interpolate-0.3.4.0-7G06fvGzHlv6EQif7jBdNQ
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-BAx0nW43BWmJb9h46BesnM
    unix-2.7.3 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-2If6MrCrP3g55Bnhb5dowG
    vty-6.2-B7lVRbyXX0969KhC7oKvuC
    vty-crossplatform-0.4.0.0-GMkb7HLFhqi5pBV0IFbROQ

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandwich-0.2.0.0-61-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandwich.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sandwich
version:              0.2.0.0
visibility:           public
id:                   sandwich-0.2.0.0-9tbFAHizFPT1dcFfoeR3zZ
key:                  sandwich-0.2.0.0-9tbFAHizFPT1dcFfoeR3zZ
license:              BSD-3-Clause
copyright:            2023 Tom McLaughlin
maintainer:           tom@codedown.io
author:               Tom McLaughlin
homepage:             https://codedownio.github.io/sandwich
synopsis:             Yet another test framework for Haskell
description:
    Please see the <https://codedownio.github.io/sandwich documentation>.

category:             Testing
abi:                  d56de188aad54d4d7e446c8959e1345c
exposed:              True
exposed-modules:
    Test.Sandwich Test.Sandwich.Contexts Test.Sandwich.Expectations
    Test.Sandwich.Formatters.FailureReport
    Test.Sandwich.Formatters.LogSaver Test.Sandwich.Formatters.Print
    Test.Sandwich.Formatters.Silent Test.Sandwich.Formatters.TerminalUI
    Test.Sandwich.Golden Test.Sandwich.Internal Test.Sandwich.Logging
    Test.Sandwich.Misc Test.Sandwich.Nodes Test.Sandwich.Options
    Test.Sandwich.TH

hidden-modules:
    Test.Sandwich.ArgParsing Test.Sandwich.Formatters.Common.Count
    Test.Sandwich.Formatters.Common.Util
    Test.Sandwich.Formatters.MarkdownSummary
    Test.Sandwich.Formatters.Print.CallStacks
    Test.Sandwich.Formatters.Print.Color
    Test.Sandwich.Formatters.Print.Common
    Test.Sandwich.Formatters.Print.FailureReason
    Test.Sandwich.Formatters.Print.Logs
    Test.Sandwich.Formatters.Print.Printing
    Test.Sandwich.Formatters.Print.PrintPretty
    Test.Sandwich.Formatters.Print.Types
    Test.Sandwich.Formatters.Print.Util
    Test.Sandwich.Formatters.TerminalUI.AttrMap
    Test.Sandwich.Formatters.TerminalUI.CrossPlatform
    Test.Sandwich.Formatters.TerminalUI.Draw
    Test.Sandwich.Formatters.TerminalUI.Draw.ColorProgressBar
    Test.Sandwich.Formatters.TerminalUI.Draw.RunTimes
    Test.Sandwich.Formatters.TerminalUI.Draw.ToBrickWidget
    Test.Sandwich.Formatters.TerminalUI.Draw.TopBox
    Test.Sandwich.Formatters.TerminalUI.Draw.Util
    Test.Sandwich.Formatters.TerminalUI.Filter
    Test.Sandwich.Formatters.TerminalUI.Keys
    Test.Sandwich.Formatters.TerminalUI.OpenInEditor
    Test.Sandwich.Formatters.TerminalUI.Types
    Test.Sandwich.Golden.Update Test.Sandwich.Internal.Formatters
    Test.Sandwich.Internal.Running
    Test.Sandwich.Interpreters.FilterTree
    Test.Sandwich.Interpreters.FilterTreeModule
    Test.Sandwich.Interpreters.PrettyShow
    Test.Sandwich.Interpreters.PruneTree
    Test.Sandwich.Interpreters.RunTree
    Test.Sandwich.Interpreters.RunTree.Logging
    Test.Sandwich.Interpreters.RunTree.Util
    Test.Sandwich.Interpreters.StartTree Test.Sandwich.ParallelN
    Test.Sandwich.RunTree Test.Sandwich.Shutdown Test.Sandwich.Signals
    Test.Sandwich.TestTimer Test.Sandwich.TH.HasMainFunction
    Test.Sandwich.TH.ModuleMap Test.Sandwich.Types.ArgParsing
    Test.Sandwich.Types.General Test.Sandwich.Types.RunTree
    Test.Sandwich.Types.Spec Test.Sandwich.Types.TestTimer
    Test.Sandwich.Types.TestTimer.LensRules Test.Sandwich.Util
    Paths_sandwich

import-dirs:          /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sandwich-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sandwich
hs-libraries:         HSsandwich-0.2.0.0-9tbFAHizFPT1dcFfoeR3zZ
depends:
    aeson-2.1.2.1-HvDDR856aNq5cfhhuYXFVB
    ansi-terminal-1.0.2-HjENL9BIUVI6RnTwgiyfuy
    async-2.2.5-6I3Om2iOc9KLV2rb6dASmz base-4.17.2.1
    brick-2.2-J4RRcRpctaPBTTKbl8gvjI bytestring-0.11.5.3
    colour-2.3.6-10HMlntjl8LargK6NvvQt containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    free-5.2-KHHkmu51Uvs7lnbXoJINPa
    haskell-src-exts-1.23.1-A4ZL9v1MkyK75Sk0IlbUyj
    lifted-async-0.10.2.7-IbeycPYyfCnFsL3YlKnqxG
    microlens-0.4.14.0-71jOCsiFFF8LaovsPy6HDt
    microlens-th-0.4.3.17-GRXwDxs8Aw09PQskuAg669
    monad-control-1.0.3.1-GYvvySxcDDsKr3A3afhWG
    monad-logger-0.3.42-9OgDnhfMjyd9Av4VLmtX3H mtl-2.2.2
    optparse-applicative-0.18.1.0-6vzfjdGcscpK23HoS6KcvN
    pretty-show-1.10-Ey6CADemQl3EFi7OIHqHDp process-1.6.18.0
    safe-0.3.21-3NYlWmvK5NXAlxNW2aDsvC
    safe-exceptions-0.1.7.4-43DSHUzp09v7o2yrgwFUvA stm-2.5.1.0
    string-interpolate-0.3.4.0-DUeKwujifjaBRe28Otrvwl
    template-haskell-2.19.0.0 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 transformers-base-0.4.6-7u55LZmMXS5CMak7FcNNxB
    unix-2.7.3 unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT
    vector-0.13.2.0-4gUGda2ISIbCv9ACnxMPCL
    vty-6.2-6jZylV5u3mR8jwdkpkHoeB
    vty-crossplatform-0.4.0.0-FUyecyTiyFSAcAj5n9fmkS

haddock-interfaces:   /usr/share/doc/haskell-sandwich/html/sandwich.haddock
haddock-html:         /usr/share/doc/haskell-sandwich/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
